OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Але якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true.",
    "See %s" : "Переглянути %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Застосунок %1$s відсутній або має несумісну з цим сервером версію. Будь ласка, перевірте каталог додатків.",
    "Sample configuration detected" : "Виявлено приклад конфігурації",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
    "The page could not be found on the server." : "Сторінку не знайдено на сервері.",
    "%s email verification" : "%s підтвердження електронної пошти",
    "Email verification" : "Підтвердження електронної пошти",
    "Click the following button to confirm your email." : "Натисніть наступну кнопку, щоб підтвердити свою електронну адресу.",
    "Click the following link to confirm your email." : "Натисніть це посилання, щоб підтвердити свою електронну адресу.",
    "Confirm your email" : "Підтвердьте свою електронну адресу",
    "Other activities" : "Інша активність",
    "%1$s and %2$s" : "%1$s та %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s та %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s та %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s та %5$s",
    "Education bundle" : "Освіта",
    "Enterprise bundle" : "Для бізнесу",
    "Groupware bundle" : "Для робочих груп",
    "Hub bundle" : "Основні застосунки",
    "Public sector bundle" : "Для громадських організацій",
    "Social sharing bundle" : "Для соціальних мереж",
    "PHP %s or higher is required." : "Необхідно PHP %s або вище",
    "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
    "%sbit or higher PHP required." : "%sнеобхідний PHP біт або вище.",
    "The following architectures are supported: %s" : "Підтримуються такі архітектури: %s",
    "The following databases are supported: %s" : "Підтримуються такі бази даних: %s",
    "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
    "The library %s is not available." : "Бібліотека %s недоступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Бібліотека %1$s з версією вищою за необхідну %2$s - доступна версія %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Бібліотека %1$s з версією нижчою за необхідну %2$s - доступна версія %3$s.",
    "The following platforms are supported: %s" : "Підтримуються такі платформи: %s",
    "Server version %s or higher is required." : "Потрібна версія сервера %s або вище.",
    "Server version %s or lower is required." : "Потрібна версія сервера %s або нижча.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора або мати спеціальні права доступу до цих налаштувань.",
    "Your current IP address doesn't allow you to perform admin actions" : "Ваша поточна адреса IP не дозволяє вам виконувати адміністративні дії",
    "Logged in account must be an admin or sub admin" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора",
    "Logged in account must be an admin" : "Обліковий запис для входу має бути адміністратором",
    "Wiping of device %s has started" : "Розпочато очищення пристрою %s",
    "Wiping of device »%s« has started" : "Розпочато стирання даних на пристрої \"%s\".",
    "»%s« started remote wipe" : "\"%s\" розпочато віддалене стирання даних",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Пристрій або застосунок \"%s\" розпочали процес віддаленого стирання даних. Після завершення процесу ви отримаєте відповідне сповіщення електронною поштою.",
    "Wiping of device %s has finished" : "Очищення пристрою %s завершено",
    "Wiping of device »%s« has finished" : "Стирання даних на пристрої \"%s\" завершено",
    "»%s« finished remote wipe" : "\"%s\" віддалене очищення стирання даних",
    "Device or application »%s« has finished the remote wipe process." : "Пристрій або застосунок \"%s\" завершили процес віддаленого стирання даних.",
    "Remote wipe started" : "Розпочато віддалене стирання",
    "A remote wipe was started on device %s" : "На пристрої %s розпочато віддалене стирання",
    "Remote wipe finished" : "Віддалене стирання завершено",
    "The remote wipe on %s has finished" : "Дистанційне стирання на %s завершено",
    "Authentication" : "Авторизація",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Недійсне зображення",
    "Avatar image is not square" : "Зображення аватара не квадратне",
    "Files" : "Файли",
    "View profile" : "Перегляд профілю",
    "same time" : "той саме час",
    "_%nh_::_%nh_" : ["%n год","%n год","%n год","%n год"],
    "_%nm_::_%nm_" : ["%n хв","%n хв","%n хв","%n хв"],
    "%s ahead" : "%s попереду",
    "%s behind" : "%s позаду",
    "Local time: %s" : "Місцевий час: %s",
    "today" : "сьогодні",
    "tomorrow" : "завтра",
    "yesterday" : "вчора",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дні","через %n днів","через %n днів"],
    "_%n day ago_::_%n days ago_" : ["%n день тому","%n днів тому","%n днів тому","%n днів тому"],
    "next month" : "наступноого місяця",
    "last month" : "минулого місяця",
    "_in %n month_::_in %n months_" : ["в %n місяць","в %n місяцях","в %n місяцях","в %n місяцях"],
    "_%n month ago_::_%n months ago_" : ["%n місяць тому","%n місяць тому","%n місяців тому","%n місяців тому"],
    "next year" : "наступного року",
    "last year" : "минулого року",
    "_in %n year_::_in %n years_" : ["в %n рік","в %n роках","в %n роках","в %n роках"],
    "_%n year ago_::_%n years ago_" : ["%n рік тому","%n років тому","%n років тому","%n років тому"],
    "_in %n hour_::_in %n hours_" : ["в %n годин","в %n годинах","в %n годинах","в %n годинах"],
    "_%n hour ago_::_%n hours ago_" : ["%nгодину тому","%n годин тому","%n годин тому","%n годин тому"],
    "_in %n minute_::_in %n minutes_" : ["за %n хвилину","за %n хвилин","за %n хвилин","за %n хвилин"],
    "_%n minute ago_::_%n minutes ago_" : ["%n хвилину тому","%n хвилин тому","%n хвилин тому","%n хвилин тому"],
    "in a few seconds" : "через кілька секунд",
    "seconds ago" : "кілька секунд тому",
    "Empty file" : "Порожній файл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з ID: %s не існує. Будь ласка, увімкніть це в налаштуваннях застосунку або зверніться до адміністратора.",
    "No file conversion providers available" : "Відсутні постачальники послуг з конвертування",
    "File is too large to convert" : "Файл завеликий для конвертування",
    "Destination does not match conversion extension" : "Призначення не відповідає розширенню конвертування",
    "Could not convert file" : "Неможливо сконвертувати файл",
    "Destination does not exist" : "Призначення відсутнє",
    "Destination is not creatable" : "Неможливо створити призначення",
    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
    "%1$s (renamed)" : "%1$s (перейменовано)",
    "renamed file" : "перейменовано файл",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" є недозволеним ім'ям файлів або каталогів.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" є недозволеним префіксом у іменах файлів або каталоів.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" не дозволено всередині імени файлів або каталогів.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" є недозволеним типом файлів.",
    "Filenames must not end with \"%1$s\"." : "Ім'я файлу не може закінчуватися на \"%1$s\".",
    "Invalid parent path" : "Недійсний батьківський шлях",
    "File already exists" : "Файл вже існує",
    "Invalid path" : "Недійсний шлях",
    "Failed to create file from template" : "Не вдалося створити файл із шаблону",
    "Templates" : "Шаблони",
    "Storage %s cannot be moved" : "Неможливо перемістити сховище даних %s",
    "Moving a share (%s) into a shared folder is not allowed" : "Переміщення спільного ресурсу (%s) до спільного каталогу не дозволено",
    "Moving a storage (%s) into a shared folder is not allowed" : "Переміщення сховища (%s) до спільного каталогу не дозволено",
    "Moving a share (%s) into another share (%s) is not allowed" : "Переміщення спільного ресурсу (%s) до іншого спільного ресурсу (%s) не дозволено",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Переміщення спільного ресурсу (%s) до іншого сховища (%s) не дозволено",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Переміщення сховища (%s) до спільного ресурсу (%s) не дозволено",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Переміщення сховища (%s) до іншого сховища (%s) не дозволено",
    "Path contains invalid segments" : "Шлях містить недійсні елементи в назві",
    "Filename is a reserved word" : "Ім'я файлу є зарезервованим словом",
    "Filename contains at least one invalid character" : "У назві файлу міститься щонайменше один неправильний символ",
    "Filename is too long" : "Ім'я файлу задовге",
    "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Застосунок \"%s\" неможливо встановити, оскільки він не сумісний з цією версією сервера.",
    "__language_name__" : "Українська",
    "This is an automatically sent email, please do not reply." : "Це автоматично надісланий електронний лист, будь ласка, не відповідайте на нього.",
    "Help & privacy" : "Допомога та приватність",
    "Appearance and accessibility" : "Тема та вигляд",
    "Apps" : "Застосунки",
    "Personal settings" : "Мої налаштування",
    "Administration settings" : "Адміністрування",
    "Settings" : "Налаштування",
    "Log out" : "Вихід",
    "Accounts" : "Облікові записи",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Переглянути %s в Bluesky",
    "Email" : "Електронна пошта",
    "Mail %s" : "Пошта %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Переглянути %s у Fediverse",
    "Phone" : "Телефон",
    "Call %s" : "Телефонуйте %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Переглянути %s в Twitter",
    "Website" : "Вебсайт",
    "Visit %s" : "Відвідайте %s",
    "Address" : "Адреса",
    "Profile picture" : "Зображення користувача",
    "About" : "Опис",
    "Display name" : "Ім'я для показу",
    "Headline" : "Заголовок",
    "Organization" : "Організація роботи",
    "Role" : "Роль",
    "Pronouns" : "Займенники",
    "Unknown account" : "Невідомий обліковий запис",
    "Additional settings" : "Додатково",
    "Enter the database Login and name for %s" : "Введіть ім’я користувача та назву бази даних для %s",
    "Enter the database Login for %s" : "Введіть ім'я користувача бази даних для %s",
    "Enter the database name for %s" : "Введіть назву бази даних для %s",
    "You cannot use dots in the database name %s" : "Не можна використовувати крапки в назві бази даних %s",
    "MySQL Login and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
    "You need to enter details of an existing account." : "Потрібно ввести дані наявного облікового запису.",
    "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
    "Oracle Login and/or password not valid" : "Ім'я користувача та/або пароль Oracle не дійсні",
    "PostgreSQL Login and/or password not valid" : "Ім'я користувача та/або пароль PostgreSQL не дійсні",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не підтримується, отже %s не працюватиме належним чиним на цій платформі. Використовуйте на ваш страх і ризик.",
    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ймовірно, що сервер %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
    "Set an admin Login." : "Встановіть ім'я облікового запису адміністратора.",
    "Set an admin password." : "Встановіть пароль адміністратора.",
    "Cannot create or write into the data directory %s" : "Неможливо створити або записати в каталог даних %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
    "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
    "%1$s shared %2$s with you" : "%1$s поділив(ла)ся %2$s з вами",
    "Open %s" : "Відкрити %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s поділив(ла)ся %2$s з вами та бажає додати:",
    "%1$s shared %2$s with you and wants to add" : "%1$s поділив(ла)ся %2$s з вами та бажає додати",
    "%s added a note to a file shared with you" : "%s додав(-ла) примітку до файлу, яким поділилися з вами",
    "Passwords are enforced for link and mail shares" : "Для надання доступу до спільних ресурсів через посилання та ел. пошту має бути встановлено пароль на ресурс",
    "Share recipient is not a valid user" : "Такий отримувач спільного ресурсу відсутній",
    "Share recipient is not a valid group" : "Така група спільного ресурсу відсутня",
    "Share recipient should be empty" : "Значення отримувача ресурсу має бути порожнє",
    "Share recipient should not be empty" : "Значення отримувача ресурсу не має бути порожнє",
    "Share recipient is not a valid circle" : "Отримувач ресурсу відсутній у застосунку \"Кола\"",
    "Unknown share type" : "Невідомий тип спільного ресурсу",
    "Share initiator must be set" : "Потрібно встановити ініціатора надання ресурсу у спільний доступ",
    "Cannot share with yourself" : "Неможливо поділитися з самим(-ою) собою",
    "Shared path must be set" : "Потрібно встановити шлях спільного ресурсу",
    "Shared path must be either a file or a folder" : "Шлях спільного ресурсу має бути або файлом, або каталогом",
    "You cannot share your root folder" : "Ви не можете надавати у спільний доступ кореневий каталог",
    "You are not allowed to share %s" : "Вам заборонено поширювати %s",
    "Valid permissions are required for sharing" : "Потрібний чинний дозвіл для надання у спільний доступ",
    "File shares cannot have create or delete permissions" : "Відсутні дозволи сторення або вилучення для спільних файлів",
    "Cannot increase permissions of %s" : "Не вдалося підвищити дозволи для %s",
    "Shares need at least read permissions" : "Для спільних ресурсів має визначено щонайменше дозвіл на читання",
    "Files cannot be shared with delete permissions" : "Не можна надавати у спільний доступ файли з дозволами на вилучення",
    "Files cannot be shared with create permissions" : "Не можна ділитися файлами з дозволом на створення",
    "Expiration date is in the past" : "Дата закінчення в минулому",
    "Expiration date is enforced" : "Потрібно встановити термін завершення доступу",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможливо встановити дату закінчення більше ніж %n день у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому"],
    "Sharing is only allowed with group members" : "Спільний доступ дозволений лише для учасників групи",
    "Sharing %s failed, because this item is already shared with the account %s" : "Не вдалося надати у спільний доступ%s, оскільки цей ресурс вже у спільному доступі з обліковим записом %s",
    "Group sharing is now allowed" : "Тепер дозволено спільний доступ для груп",
    "Sharing is only allowed within your own groups" : "Спільний доступ дозволено в рамках ваших груп",
    "Path is already shared with this group" : "Шлях вже надано у спільний доступ для цієї групи",
    "Link sharing is not allowed" : "Спільний доступ через посилання не дозволено",
    "Public upload is not allowed" : "Публічні завантаження не дозволено",
    "You cannot share a folder that contains other shares" : "Неможливо надати у спільний доступ каталог, який вже містить інші спільні ресурси",
    "Sharing is disabled" : "Спільний доступ вимкнено",
    "Sharing is disabled for you" : "Ви не маєте права надавати у доступ файли або каталоги",
    "Cannot share with the share owner" : "Неможливо надавати у доступ власникові спільного ресурсу",
    "Share does not have a full ID" : "Спільний ресурс не має повного ідентифікатора",
    "Cannot change share type" : "Неможливо змінити тип спільного ресурсу",
    "Can only update recipient on user shares" : "Можна лише оновити отримувача для спільних ресурсів користувача",
    "Cannot enable sending the password by Talk with an empty password" : "Не вдалося увімкнути надсилання паролю за допомогою Talk з порожнім паролем",
    "Cannot enable sending the password by Talk without setting a new password" : "Не вдалося увімкнути надсилання паролю за допомогою Talk без встановлення нового паролю",
    "Cannot disable sending the password by Talk without setting a new password" : "Не вдалося вимкнути надсилання паролю за допомогою Talk без встановлення нового паролю",
    "Share provider does not support accepting" : "Провайдер спільного доступу не підтримує прийняття",
    "Cannot change target of link share" : "Неможливо змінити призначення для спільного ресурсу через посилання",
    "Invalid share recipient" : "Недійсний отримувач спільного ресурсу",
    "Group \"%s\" does not exist" : "Група \"%s\" відсутня",
    "The requested share does not exist anymore" : "Запитуваний спільний ресурс більше недоступний",
    "The requested share comes from a disabled user" : "Отримано запит на спільний доступ від неактивного користувача",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Користувача не створено, оскільки досягнуто обмеження на кількість користувачів. Перевірте сповіщення для докладної інформації.",
    "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
    "Input text" : "Текст для введення",
    "The input text" : "Текст для введення",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sun." : "Нд.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Нд.",
    "Mo" : "Пн.",
    "Tu" : "Вт.",
    "We" : "Ср.",
    "Th" : "Чт.",
    "Fr" : "Пт.",
    "Sa" : "Сб.",
    "January" : "Січень",
    "February" : "Лютий",
    "March" : "Березень",
    "April" : "Квітень",
    "May" : "Травень",
    "June" : "Червень",
    "July" : "Липень",
    "August" : "Серпень",
    "September" : "Вересень",
    "October" : "Жовтень",
    "November" : "Листопад",
    "December" : "Грудень",
    "Jan." : "Січ.",
    "Feb." : "Лют.",
    "Mar." : "Бер.",
    "Apr." : "Кві.",
    "May." : "Тра.",
    "Jun." : "Чер.",
    "Jul." : "Лип.",
    "Aug." : "Сер.",
    "Sep." : "Вер.",
    "Oct." : "Жов.",
    "Nov." : "Лис.",
    "Dec." : "Гру.",
    "A valid password must be provided" : "Потрібно зазначити дійсний пароль",
    "The Login is already being used" : "Це ім'я облікового запису вже використовується",
    "Could not create account" : "Не вдалося створити обліковий запис",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені облікового запису: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
    "A valid Login must be provided" : "Зазначте дійсне ім'я користувача",
    "Login contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу на початку або наприкінці",
    "Login must not consist of dots only" : "Ім'я користувача не може складатися лише з крапок",
    "Username is too long" : "Ім'я користувача задовге",
    "Login is invalid because files already exist for this user" : "Недійсне ім'я облікового запису, оскільки файли для цього користувача вже присутні",
    "Account disabled" : "Обліковий запис вимкнено",
    "Login canceled by app" : "Вхід скасовано застосунком",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Застосунок \"%1$s\" неможливо встановити, оскільки не виконано такі залежності: %2$s",
    "a safe home for all your data" : "безпечна домівка для ваших даних",
    "Application is not enabled" : "Застосунок не увімкнено",
    "Authentication error" : "Помилка авторизації",
    "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory." : "Не вдається записати в каталог \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації. Побачити %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Або, якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true. Побачити %s",
    "Cannot create \"data\" directory." : "Неможливо створити каталог \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволи зазвичай можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s. ",
    "Your data directory is not writable." : "Ваш каталог даних не доступний для запису.",
    "Setting locale to %s failed." : "Помилка налаштування мови %s.",
    "Please install one of these locales on your system and restart your web server." : "Установіть одну з цих локалей у вашій системі та перезапустіть веб-сервер.",
    "PHP module %s not installed." : "%s модуль PHP не встановлено.",
    "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Налаштування цього параметра у php.ini змусить Nextcloud запуститися знову",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на обрізання блоків вбудованих документів. Це зробить кілька головних застосунків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
    "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
    "The required %s config variable is not configured in the config.php file." : "Необхідна змінна конфігурації %s не налаштована у файлі config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Будь ласка, попросіть свого адміністратора сервера перевірити конфігурацію Nextcloud.",
    "Your data directory is readable by other people." : "Ваш каталог даних доступний для читання для інших користувачів.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
    "Your data directory must be an absolute path." : "Ваш каталог даних має бути абсолютним шляхом.",
    "Check the value of \"datadirectory\" in your configuration." : "Перевірте значення «каталогу даних» у вашій конфігурації.",
    "Your data directory is invalid." : "Ваш каталог даних недійсний.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Перевірте, що в корені каталогу з даними присутній файл \"%1$s\". Він має містити: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Дія \"%s\" не підтримується або не реалізована.",
    "Authentication failed, wrong token or provider ID given" : "Помилка авторизації, надано неправильний токен або ідентифікатор постачальника",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Немає параметрів для виконання запиту. Відсутні параметри: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Ідентифікатор \"%1$s\" уже використовується постачальником об'єднаних хмар \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Постачальник Cloud Federation з ідентифікатором \"%s\" не існує.",
    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
    "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
    "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
    "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Щоби дозволити запуск цієї перевірки, потрібно пересвідчитися, що ваш вебсервер може з'єднуватися з самим собою, що передбачає можливість резолвити та з'єднуватися з одним з `trusted_domains` або `overwrite.cli.url`. Неможливість цього може бути результатом незбігу DNS на стороні сервера або встановленими правилами брандмауера.",
    "Analyze images" : "Аналізуйте зображення",
    "Ask a question about the given images." : "Поставте запитання про наведені зображення.",
    "Images" : "Зображення",
    "Images to ask a question about" : "Зображення, про які можна задати питання",
    "Question" : "Питання",
    "What to ask about the images." : "Що запитати про зображення.",
    "Generated response" : "Згенерована відповідь",
    "The answer to the question" : "Відповідь на питання",
    "Audio chat" : "Аудіо чат",
    "Voice chat with the assistant" : "Голосовий чат з асистентом",
    "System prompt" : "Системний запит",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Визначте правила та припущення, яких асистент повинен дотримуватися під час розмови.",
    "Chat voice message" : "Голосове повідомлення в чаті",
    "Describe a task that you want the assistant to do or ask a question." : "Опишіть завдання, яке ви хочете, щоб асистент виконав, або поставте запитання.",
    "Chat history" : "Історія чату",
    "The history of chat messages before the current message, starting with a message by the user." : "Історія повідомлень чату перед поточним повідомленням, починаючи з повідомлення користувача.",
    "Input transcript" : "Вхідна стенограма",
    "Transcription of the audio input" : "Транскрипція аудіовходу",
    "Response voice message" : "Голосове повідомлення у відповідь",
    "The generated voice response as part of the conversation" : "Згенерована голосова відповідь як частина розмови",
    "Output transcript" : "Вихідна розшифровка",
    "Transcription of the audio output" : "Транскрипція аудіовиходу",
    "Transcribe audio" : "Транскрибувати аудіо",
    "Transcribe the things said in an audio" : "Транскрибувати голос",
    "Audio input" : "Аудіовхід",
    "The audio to transcribe" : "Аудіо для транскрибування",
    "Transcription" : "Транскрипція",
    "The transcribed text" : "Транскрибований текст",
    "Chat by voice with an agent" : "Голосовий чат з агентом",
    "Describe a task that you want the agent to do or ask a question." : "Опишіть завдання, яке ви хочете, щоб агент виконав, або поставте запитання.",
    "Confirmation" : "Підтвердження",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Чи підтверджувати раніше запитані дії: 0 для відмови та 1 для підтвердження.",
    "Conversation token" : "Токен розмови",
    "A token representing the conversation." : "Токен, що представляє розмову.",
    "The new conversation token" : "Новий токен розмови",
    "Send this along with the next interaction." : "Надішліть це разом з наступною взаємодією.",
    "Requested actions by the agent" : "Необхідні дії агента",
    "Actions that the agent would like to carry out in JSON format." : "Дії, які агент хотів би виконати у форматі JSON.",
    "Chat with an agent" : "Чат з агентом",
    "Chat message" : "Повідомлення в чаті",
    "A chat message to send to the agent." : "Повідомлення в чаті для відправки агенту.",
    "The response from the chat model." : "Відповідь від чат-моделі.",
    "Context write" : "Контекстний запис",
    "Writes text in a given style based on the provided source material." : "Пише текст у заданому стилі на основі наданого вихідного матеріалу.",
    "Writing style" : "Стиль письма",
    "Demonstrate a writing style that you would like to immitate" : "Продемонструйте стиль письма, який ви хотіли б наслідувати",
    "Source material" : "Вихідний матеріал",
    "The content that would like to be rewritten in the new writing style" : "Контент, який хотілося б переписати в новому стилі",
    "Generated text" : "Зґенерований текст",
    "The generated text with content from the source material in the given style" : "Згенерований текст з вмістом з вихідного матеріалу в заданому стилі",
    "Emoji generator" : "Ґенератор емоційок",
    "Takes text and generates a representative emoji for it." : "Бере текст і генерує для нього відповідний емодзі.",
    "The text to generate an emoji for" : "Текст для створення емодзі для",
    "Generated emoji" : "Зґенеровані емоційки",
    "The generated emoji based on the input text" : "Згенеровані емодзі на основі введеного тексту",
    "Generate image" : "Зґенерувати зображення",
    "Generate an image from a text prompt" : "Створити зображення з текстової підказки",
    "Prompt" : "Запрошення",
    "Describe the image you want to generate" : "Опишіть зображення, яке ви хочете створити",
    "Number of images" : "Кількість зображень",
    "How many images to generate" : "Скільки зображень генерувати",
    "Output images" : "Вихідні зображення",
    "The generated images" : "Згенеровані зображення",
    "Generate speech" : "Генерування мовлення",
    "Generate speech from a transcript" : "Створюйте мовлення з транскрипту",
    "Write transcript that you want the assistant to generate speech from" : "Напишіть стенограму, з якої ви хочете, щоб асистент генерував мовлення",
    "Output speech" : "Вихідне мовлення",
    "The generated speech" : "Згенероване мовлення",
    "Free text to text prompt" : "Безкоштовна підказка з тексту на текст",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Запускає довільний запит через мовну модель, яка повертає відповідь",
    "Describe a task that you want the assistant to do or ask a question" : "Опишіть завдання, яке ви хочете, щоб асистент виконав, або поставте запитання",
    "Generated reply" : "Згенерована відповідь",
    "The generated text from the assistant" : "Згенерований текст від помічника",
    "Change Tone" : "Змінити тон",
    "Change the tone of a piece of text." : "Змініть тон фрагмента тексту.",
    "Write a text that you want the assistant to rewrite in another tone." : "Напишіть текст, який ви хочете, щоб асистент переписав в іншій тональності.",
    "Desired tone" : "Бажаний тон",
    "In which tone should your text be rewritten?" : "В якій тональності переписувати текст?",
    "The rewritten text in the desired tone, written by the assistant:" : "Переписаний текст у потрібній тональності, написаний асистентом:",
    "Chat" : "Чат",
    "Chat with the assistant" : "Чат з асистентом",
    "The history of chat messages before the current message, starting with a message by the user" : "Історія повідомлень чату перед поточним повідомленням, починаючи з повідомлення користувача",
    "Response message" : "Відповідь",
    "The generated response as part of the conversation" : "Згенерована відповідь як частина розмови",
    "Chat with tools" : "Чат з інструментами",
    "Chat with the language model with tool calling support." : "Чат з мовною моделлю з підтримкою виклику інструментів.",
    "Tool message" : "Повідомлення про інструмент",
    "The result of tool calls in the last interaction" : "Результат викликів інструментів в останній взаємодії",
    "Available tools" : "Доступні інструменти",
    "The available tools in JSON format" : "Доступні інструменти у форматі JSON",
    "The response from the chat model" : "Відповідь від чат-моделі",
    "Tool calls" : "Виклики інструментів",
    "Tools call instructions from the model in JSON format" : "Інструменти викликають інструкції з моделі у форматі JSON",
    "Formalize text" : "Формалізуйте текст",
    "Takes a text and makes it sound more formal" : "Бере текст і робить його більш формальним",
    "Write a text that you want the assistant to formalize" : "Напишіть текст, який ви хочете, щоб асистент оформив",
    "Formalized text" : "Формалізований текст",
    "The formalized text" : "Формалізований текст",
    "Generate a headline" : "Створіть заголовок",
    "Generates a possible headline for a text." : "Створює ймовірний заголовок тексту.",
    "Original text" : "Оригінальний текст",
    "The original text to generate a headline for" : "Вихідний текст для створення заголовка для",
    "The generated headline" : "Згенерований заголовок",
    "Proofread" : "Вичитано",
    "Proofreads a text and lists corrections" : "Вичитує текст і складає список виправлень",
    "Text" : "Текст",
    "The text to proofread" : "Текст для вичитки",
    "Corrections" : "Виправлення",
    "The corrections that should be made in your text" : "Виправлення, які слід зробити у вашому тексті",
    "Reformulate text" : "Переформатуйте текст",
    "Takes a text and reformulates it" : "Бере текст і переформатовує його",
    "Write a text that you want the assistant to reformulate" : "Напишіть текст, який ви хочете, щоб асистент переформулював",
    "Reformulated text" : "Переформульований текст",
    "The reformulated text, written by the assistant" : "Переформульований текст, написаний асистентом",
    "Simplify text" : "Спростити текст",
    "Takes a text and simplifies it" : "Бере текст і спрощує його",
    "Write a text that you want the assistant to simplify" : "Напишіть текст, який ви хочете, щоб асистент спростив",
    "Simplified text" : "Спрощений текст",
    "The simplified text" : "Спрощений текст",
    "Summarize" : "Підсумок",
    "Summarizes a text" : "Підсумовує текст",
    "The original text to summarize" : "Оригінальний текст для підбиття підсумків",
    "Summary" : "Загалом",
    "The generated summary" : "Згенерований підсумок",
    "Extract topics" : "Виділити теми",
    "Extracts topics from a text and outputs them separated by commas" : "Витягує теми з тексту і виводить їх через кому",
    "The original text to extract topics from" : "Оригінальний текст, з якого можна взяти теми",
    "Topics" : "Теми",
    "The list of extracted topics" : "Список витягнутих тем",
    "Translate" : "Перекласти",
    "Translate text from one language to another" : "Перекладіть текст з однієї мови на іншу",
    "Origin text" : "Вихідний текст",
    "The text to translate" : "Текст для перекладу",
    "Origin language" : "Мова походження",
    "The language of the origin text" : "Мова оригінального тексту",
    "Target language" : "Цільова мова",
    "The desired language to translate the origin text in" : "Бажана мова для перекладу вихідного тексту",
    "Result" : "Результат",
    "The translated text" : "Перекладений текст",
    "Free prompt" : "Вільне запрошення",
    "Runs an arbitrary prompt through the language model." : "Виконує довільне запрошення через мовну модель.",
    "Generate headline" : "Створити заголовок",
    "Summarizes text by reducing its length without losing key information." : "Викокремлює головне у тексті шляхом зменшення довжини тексту без втрати ключової інформації.",
    "Extracts topics from a text and outputs them separated by commas." : "Виділяє теми, які висвітлює текст, зводить їх у перелік, що розділено комами.",
    "Organisation" : "Організація",
    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
    "Cannot download file" : "Неможливо звантажити файл",
    "Cannot write into \"apps\" directory." : "Відсутній доступ на запис до каталогу застосунків \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Зазвичай це можна виправити, якщо надати вебсерверу доступ для запису до каталогу застосунків або вимкнути App Store у конфігураційному файлі.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> замість <code>%s</code> очікуваного значення <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Щоб вирішити цю проблему, установіть для <code>mbstring.func_overload</code> значення <code>0</code> у вашому php.ini.",
    "Login is too long" : "Ім'я користувача для авторизації задовге"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
